package com.ruoyi.ems.service.impl;

import java.util.List;

import com.ruoyi.ems.domain.PowerBoxElecEqpt;
import com.ruoyi.ems.mapper.PowerBoxElecEqptMapper;
import com.ruoyi.ems.service.IPowerBoxElecEqptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 动力箱柜电气设备Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
@Service
public class PowerBoxElecEqptServiceImpl implements IPowerBoxElecEqptService
{
    @Autowired
    private PowerBoxElecEqptMapper boxElecEqptMapper;

    /**
     * 查询动力箱柜电气设备
     * 
     * @param id 动力箱柜电气设备主键
     * @return 动力箱柜电气设备
     */
    @Override
    public PowerBoxElecEqpt selectBoxElecEqptById(Long id)
    {
        return boxElecEqptMapper.selectBoxElecEqptById(id);
    }

    @Override
    public List<PowerBoxElecEqpt> selectByBoxCode(String boxCode) {
        return boxElecEqptMapper.selectByBoxCode(boxCode);
    }

    /**
     * 查询动力箱柜电气设备列表
     * 
     * @param boxElecEqpt 动力箱柜电气设备
     * @return 动力箱柜电气设备
     */
    @Override
    public List<PowerBoxElecEqpt> selectBoxElecEqptList(PowerBoxElecEqpt boxElecEqpt)
    {
        return boxElecEqptMapper.selectBoxElecEqptList(boxElecEqpt);
    }

    /**
     * 新增动力箱柜电气设备
     * 
     * @param boxElecEqpt 动力箱柜电气设备
     * @return 结果
     */
    @Override
    public int insertBoxElecEqpt(PowerBoxElecEqpt boxElecEqpt)
    {
        return boxElecEqptMapper.insertBoxElecEqpt(boxElecEqpt);
    }

    /**
     * 批量-新增动力箱柜电气设备
     *
     * @param boxElecEqpts 动力箱柜电气设备列表
     * @return 结果
     */
    @Override
    public int insertBatch(List<PowerBoxElecEqpt> boxElecEqpts) {
        return boxElecEqptMapper.insertBatch(boxElecEqpts);
    }

    /**
     * 修改动力箱柜电气设备
     * 
     * @param boxElecEqpt 动力箱柜电气设备
     * @return 结果
     */
    @Override
    public int updateBoxElecEqpt(PowerBoxElecEqpt boxElecEqpt)
    {
        return boxElecEqptMapper.updateBoxElecEqpt(boxElecEqpt);
    }

    /**
     * 批量删除动力箱柜电气设备
     * 
     * @param ids 需要删除的动力箱柜电气设备主键
     * @return 结果
     */
    @Override
    public int deleteBoxElecEqptByIds(Long[] ids)
    {
        return boxElecEqptMapper.deleteBoxElecEqptByIds(ids);
    }

    /**
     * 删除动力箱柜电气设备信息
     * 
     * @param id 动力箱柜电气设备主键
     * @return 结果
     */
    @Override
    public int deleteBoxElecEqptById(Long id)
    {
        return boxElecEqptMapper.deleteBoxElecEqptById(id);
    }

    @Override
    public int deleteByBoxCode(String boxCode)
    {
        return boxElecEqptMapper.deleteByBoxCode(boxCode);
    }
}
