package com.ruoyi.ems.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.ems.domain.PowerBoxElecEqpt;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.service.IPowerBoxElecEqptService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 动力箱柜电气设备Controller
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
@RestController
@RequestMapping("/powerBox/elecEqpt")
@Api(value = "PowerBoxElecEqptController", description = "动力箱配电元器件管理")
public class PowerBoxElecEqptController extends BaseController
{
    @Autowired
    private IPowerBoxElecEqptService boxElecEqptService;

    /**
     * 查询动力箱柜电气设备列表
     */
    @RequiresPermissions("ems:powerBox:list")
    @GetMapping("/list")
    public TableDataInfo list(PowerBoxElecEqpt boxElecEqpt)
    {
        startPage();
        List<PowerBoxElecEqpt> list = boxElecEqptService.selectBoxElecEqptList(boxElecEqpt);
        return getDataTable(list);
    }

    /**
     * 导出动力箱柜电气设备列表
     */
    @RequiresPermissions("ems:powerBox:export")
    @Log(title = "动力箱柜电气设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PowerBoxElecEqpt boxElecEqpt)
    {
        List<PowerBoxElecEqpt> list = boxElecEqptService.selectBoxElecEqptList(boxElecEqpt);
        ExcelUtil<PowerBoxElecEqpt> util = new ExcelUtil<PowerBoxElecEqpt>(PowerBoxElecEqpt.class);
        util.exportExcel(response, list, "动力箱柜电气设备数据");
    }

    /**
     * 获取动力箱柜电气设备详细信息
     */
    @RequiresPermissions("ems:powerBox:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(boxElecEqptService.selectBoxElecEqptById(id));
    }

    /**
     * 新增动力箱柜电气设备
     */
    @RequiresPermissions("ems:powerBox:add")
    @Log(title = "动力箱柜电气设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PowerBoxElecEqpt boxElecEqpt)
    {
        return toAjax(boxElecEqptService.insertBoxElecEqpt(boxElecEqpt));
    }

    /**
     * 新增动力箱柜电气设备
     */
    @RequiresPermissions("ems:powerBox:add")
    @Log(title = "动力箱柜电气设备", businessType = BusinessType.INSERT)
    @PostMapping("/batch")
    public AjaxResult addBatch(@RequestBody List<PowerBoxElecEqpt> boxElecEqpts)
    {
        return toAjax(boxElecEqptService.insertBatch(boxElecEqpts));
    }

    /**
     * 修改动力箱柜电气设备
     */
    @RequiresPermissions("ems:powerBox:edit")
    @Log(title = "动力箱柜电气设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PowerBoxElecEqpt boxElecEqpt)
    {
        return toAjax(boxElecEqptService.updateBoxElecEqpt(boxElecEqpt));
    }

    /**
     * 删除动力箱柜电气设备
     */
    @RequiresPermissions("ems:powerBox:remove")
    @Log(title = "动力箱柜电气设备", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(boxElecEqptService.deleteBoxElecEqptByIds(ids));
    }
}
